@@ -1,4 +1,6 @@
-from amqpqueue import HTTPWorker, QueueFactory
+from amqpqueue import QueueFactory
+
+from pyworker import HTTPWorker
 
 import threading
 
