@@ -1,4 +1,6 @@
-from amqpqueue import Worker, QueueFactory
+from amqpqueue import QueueFactory
+
+from pyworker import Worker
 
 import threading
 
